#include "bisonc++.ih"
#include "VERSION"

char version[] = VERSION;
char year[] = YEARS;

